varying mediump vec2 var_texcoord0;

uniform lowp sampler2D tex0;
uniform lowp sampler2D tex1;
uniform lowp vec4 tint0;
uniform lowp vec4 tint1;

uniform lowp vec4 enable_effects1; // x is vignette, y is CRT curve, z is scanlines, w is if it is overall enabled or not
uniform lowp vec4 effects1; // x is vingnette strength, y is vignette intensity, z is crt curve, w is scanline strength

#define VIGNETTE enable_effects1.x
#define SCANLINES enable_effects1.y
#define CRT enable_effects1.z
#define HORROR_LOFI_ENABLED enable_effects1.w

#define VIG_STRENGTH effects1.x
#define VIG_INTENSITY effects1.y
#define SCAN_STRENGTH effects1.z
#define CRT_CURVE effects1.w

vec2 warp(vec2 uv){
    vec2 delta = uv - 0.5;
    float delta2 = dot(delta.xy, delta.xy);
    float delta4 = delta2 * delta2;
    float delta_offset = delta4 * CRT_CURVE;

    return uv + delta * delta_offset;
}

float vig(vec2 uv)
{
    uv *= 1.0 - uv;
    return ( pow(uv.x*uv.y*VIG_INTENSITY*10., VIG_STRENGTH) );
}

void main()
{
    // Pre-multiply alpha since all runtime textures already are
    vec4 tint0_pm = vec4(tint0.xyz * tint0.w, tint0.w);
    vec4 tint1_pm = vec4(tint1.xyz * tint1.w, tint1.w);

    vec4 color0 = texture2D(tex0, var_texcoord0.xy) * tint0_pm;
    vec4 color1 = texture2D(tex1, var_texcoord0.xy) * tint1_pm;

    vec4 color = color0 * color1;
    
    if (HORROR_LOFI_ENABLED > 0.5) {

        vec2 uv = var_texcoord0;

        // CRT effect
        if (CRT > 0.5) uv = warp(uv);

        // Pre-multiply alpha since all runtime textures already are
        // vec4 tint_pm = vec4(tint.xyz * tint.w, tint.w);
        // vec4 color = texture2D(tex0, uv) * tint_pm;

        // scanlines and vignette
        if (SCANLINES > 0.5) color.rgb *= (1.-SCAN_STRENGTH)+(sin(uv.y*1024.)*SCAN_STRENGTH);
        if (VIGNETTE > 0.5) color.rgb *= vig(uv);

        // cutoff edges
        if (CRT > 0.5 && ( uv.x<0.||uv.y<0.||uv.x>1.||uv.y>1. ))
        {
            color.rgb *= 0.;
        }

        // apply to screen
        gl_FragColor = vec4(color.rgb,1.0);
    } 
    else
    {
        gl_FragColor = color;
    }
}




